@@ -585,7 +585,7 @@ IOP_shutdown_profiles (GSList *profiles)
 void
 IOP_generate_profiles (CORBA_Object obj)
 {
-	CORBA_ORB      orb;
+	CORBA_ORB orb;
 	ORBit_OAObject adaptor_obj;
 
 	g_assert (obj && (obj->profile_list == NULL) && obj->orb);
@@ -1150,7 +1150,7 @@ CodeSetComponent_demarshal (GIOPRecvBuffer *buf,
 		if (!(warned++))
 			g_warning ("Ignoring incoming code_sets component");
 
-		if (buf->cur + sequence_length * 4 < buf->end)
+		if (buf->cur + sequence_length * 4 <= buf->end)
 			buf->cur += sequence_length * 4;
 		else
 			return FALSE;
